# fontello font demo

show codes
⌂ icon-home0x2302
▸ icon-right-dir0x25b8
▾ icon-down-dir0x25be
★ icon-star0x2605
☆ icon-star-empty0x2606
☑ icon-check-on0x2611
☰ icon-list0x2630
⚏ icon-tiles0x268f
⚑ icon-flag0x2691
⛯ icon-cog-many0x26ef
✂ icon-cut0x2702
✉ icon-mail0x2709
✍ icon-edit0x270d
✎ icon-pencil0x270e
✔ icon-ok-circle0x2714
➖ icon-minus-circle0x2796
 icon-left-circle0xe4a1
 icon-right-circle0xe4a2
 icon-user-add0xe700
 icon-radio-on0xe702
 icon-cancel-circle-open0xe703
 icon-help-circle0xe704
 icon-eye0xe70a
 icon-tag0xe70c
 icon-tags0xe70d
 icon-upload-cloud0xe711
 icon-print0xe716
 icon-vcard0xe722
 icon-trash0xe729
 icon-rss0xe73a
 icon-resize-full0xe744
 icon-resize-small0xe746
 icon-left-open0xe75d
 icon-right-open0xe75e
 icon-network0xe776
 icon-heart-empty0xe800
 icon-heart0xe801
 icon-plus-circle0xe802
 icon-cancel-circle0xe803
 icon-cog0xe804
 icon-chat0xe805
 icon-comment0xe806
 icon-list-large0xe807
 icon-upload0xe808
 icon-download0xe809
 icon-export0xe80a
 icon-grid-large0xe80b
 icon-attention0xe80c
 icon-up-circle0xe80d
 icon-down-circle0xe80e
 icon-archive0xe80f
 icon-calendar0xe810
 icon-document0xe811
 icon-brush0xe812
 icon-cancel-circle-open-light0xe813
 icon-bell0xe814
 icon-follow-empty0xe815
 icon-contacts0xe816
 icon-calendar-empty0xe817
 icon-slides0xe818
 icon-info-circle0xe819
 icon-file-pdf0xe81a
 icon-file-word0xe81b
 icon-file-excel0xe81c
 icon-file-powerpoint0xe81d
 icon-file-video0xe81e
 icon-file-code0xe81f
 icon-file-audio0xe820
 icon-file-archive0xe821
 icon-file-image0xe822
 icon-doc-text0xe823
 icon-ellipsis0xe824
 icon-plus0xe825
 icon-copy0xe826
 icon-move0xe827
 icon-share0xe828
 icon-rename0xe829
 icon-ok0xe82a
 icon-floppy0xe82b
 icon-speedometer0xe82c
 icon-location0xe82d
 icon-back-in-time0xe82e
 icon-clock0xe82f
 icon-external0xe830
 icon-plus-10xe831
 icon-right-hand0xe832
 icon-religious-jewish0xe833
 icon-religious-islam0xe834
 icon-religious-christian0xe835
 icon-phone-10xe836
 icon-box0xe837
 icon-spin0xe838
 icon-bell-alt0xe839
 icon-thumbs-up-alt0xe83a
 icon-link0xe83b
 icon-home-10xe83c
 icon-search-10xe83d
 icon-glass0xe83e
 icon-music0xe83f
 icon-newspaper0xe840
 icon-video0xe841
 icon-child0xe842
 icon-sun0xe843
 icon-globe0xe844
 icon-inbox0xe845
 icon-award0xe846
 icon-signal0xe847
 icon-briefcase0xe848
 icon-suitcase0xe849
 icon-toggle-on0xe84a
 icon-toggle-off0xe84b
 icon-bank0xe84c
 icon-gwallet0xe84d
 icon-fork0xe84e
 icon-magic0xe84f
 icon-book0xe850
 icon-bookmark0xe851
 icon-stage0xe852
 icon-money0xe853
 icon-hammer0xe854
 icon-up-open0xe855
 icon-down-open0xe856
 icon-align-left0xe857
 icon-align-center0xe858
 icon-align-right0xe859
 icon-align-justify0xe85a
 icon-list-bullet0xe85b
 icon-list-numbered0xe85c
 icon-strike0xe85d
 icon-underline0xe85e
 icon-superscript0xe85f
 icon-subscript0xe860
 icon-paragraph0xe861
 icon-bold0xe862
 icon-italic0xe863
 icon-table0xe864
 icon-ellipsis-10xe865
 icon-cw0xe866
 icon-ccw0xe867
 icon-unlink0xe868
 icon-quote-left0xe869
 icon-add-column0xe86a
 icon-add-row0xe86b
 icon-remove-column0xe86c
 icon-remove-row0xe86d
 icon-building0xe86e
 icon-squares0xe86f
 icon-newspaper-10xe870
 icon-down-bold0xe871
 icon-left-bold0xe872
 icon-right-bold0xe873
 icon-up-bold0xe874
 icon-resize-vertical0xe875
 icon-updown-circle0xe876
 icon-menu-outline0xe877
 icon-menu0xe878
 icon-manager0xe879
 icon-docs0xe87a
 icon-angle-double-right0xe87b
 icon-workspace0xe87c
 icon-bookmark-empty0xe87d
 icon-mobile0xe87e
 icon-circles0xe87f
 icon-star-circled0xe880
 icon-newspaper-angle0xe881
 icon-megaphone0xe882
 icon-lightbulb0xe883
 icon-boilerplate0xe884
 icon-history0xe885
 icon-marquee0xe886
 icon-division0xe887
 icon-right-big0xe888
 icon-arrows-cw0xe889
 icon-up-big0xe88a
 icon-feather0xe88b
 icon-follow0xe88c
 icon-check-off0xf096
 icon-paste0xf0ea
 icon-radio-off0xf10c
🌄 icon-picture0x1f304
👍 icon-thumbs-up0x1f44d
👤 icon-user0x1f464
👥 icon-users0x1f465
📁 icon-folder0x1f4c1
📌 icon-pin0x1f4cc
📎 icon-attach0x1f4ce
📞 icon-phone0x1f4de
🔍 icon-search0x1f50d
🔒 icon-lock0x1f512
🔓 icon-lock-open0x1f513
🔗 icon-link-alternative0x1f517
🔧 icon-wrench0x1f527